"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.twoot = void 0;
const toot_1 = require("./toot");
const tweet_1 = require("./tweet");
const util_1 = require("./util");
/**
 * @param statusOrStatuses A single status, or an array of statuses which will
 *                         be posted as a reply chain.
 * @param apiConfigOrConfigs The Mastodon and/or Twitter configuration(s).
 *                           Determines which accounts will be posted to.
 * @param globalConfig Global configuration for the Twoot call.
 * @returns
 */
async function twoot(statusOrStatuses, apiConfigOrConfigs, globalConfig = {}) {
    const [isSingleAPIConfig, apiConfigs] = Array.isArray(apiConfigOrConfigs)
        ? [false, apiConfigOrConfigs]
        : [true, [apiConfigOrConfigs]];
    let results;
    if (Array.isArray(statusOrStatuses)) {
        /* eslint-disable @typescript-eslint/no-throw-literal */
        const settledResults = await Promise.allSettled(apiConfigs.map((config) => config.type === "mastodon"
            ? (0, toot_1.doToots)(statusOrStatuses, config).catch((e) => {
                throw [e, config];
            })
            : (0, tweet_1.doTweets)(statusOrStatuses, config).catch((e) => {
                throw [e, config];
            })));
        /* eslint-enable @typescript-eslint/no-throw-literal */
        results = settledResults.map((r) => {
            if (r.status === "rejected") {
                return { type: "error", message: (0, util_1.formatRejection)(r) };
            }
            if ("visibility" in r.value[0]) {
                const ss = r.value;
                return {
                    type: "mastodon-chain",
                    message: ss.map(util_1.formatMastoStatus).join("\n====\n"),
                    statuses: ss,
                };
            }
            const ss = r.value;
            return {
                type: "twitter-chain",
                message: ss.map(util_1.formatTwitterStatus).join("\n====\n"),
                statuses: ss,
            };
        });
    }
    else {
        /* eslint-disable @typescript-eslint/no-throw-literal */
        const settledResults = await Promise.allSettled(apiConfigs.map((config) => config.type === "mastodon"
            ? (0, toot_1.doToot)(statusOrStatuses, config).catch((e) => {
                throw [e, config];
            })
            : (0, tweet_1.doTweet)(statusOrStatuses, config).catch((e) => {
                throw [e, config];
            })));
        /* eslint-enable @typescript-eslint/no-throw-literal */
        results = settledResults.map((r) => {
            if (r.status === "rejected") {
                return { type: "error", message: (0, util_1.formatRejection)(r) };
            }
            if ("visibility" in r.value) {
                return {
                    type: "mastodon",
                    message: (0, util_1.formatMastoStatus)(r.value),
                    status: r.value,
                };
            }
            return {
                type: "twitter",
                message: (0, util_1.formatTwitterStatus)(r.value),
                status: r.value,
            };
        });
    }
    const rejections = results.filter((r) => r.type === "error");
    if (rejections.length === results.length ||
        (rejections.length > 0 && globalConfig.rejectOnAnyFailure)) {
        throw new Error(`Failed to twoot:\n${JSON.stringify(results, undefined, 2)}`);
    }
    return isSingleAPIConfig ? results[0] : results;
}
exports.twoot = twoot;
//# sourceMappingURL=index.js.map